@@ -11,7 +11,6 @@ use crate::faddeeva::erfc;
 use crate::tilting::TiltingProblem;
 use crate::tilting::TiltingSolution;
 use crate::util;
-use levenberg_marquardt::LevenbergMarquardt;
 use ndarray::azip;
 use ndarray::Zip;
 use ndarray::{s, Axis};
@@ -263,7 +262,7 @@ pub fn solved_mv_truncnormal_rand<R: Rng + ?Sized>(
     n: usize,
     max_iters: usize,
     rng: &mut R,
-) -> (Array2<f64>, Array1<f64>) {
+) -> Array2<f64> {
     let d = l.len();
     let (Lfull, perm) = cholperm(&mut sigma, &mut l, &mut u);
     let D = Lfull.diag().to_owned();
@@ -301,7 +300,7 @@ pub fn solved_mv_truncnormal_rand<R: Rng + ?Sized>(
         accept_condition(&logp, &mut accepted, rng);
         i += 1;
         if i > max_iters {
-            //println!("Ran out of accept-reject rounds");
+            // Ran out of accept-reject rounds
             break;
         }
     }
@@ -316,7 +315,7 @@ pub fn solved_mv_truncnormal_rand<R: Rng + ?Sized>(
     for (i, &ord) in order.iter().enumerate() {
         rv.row_mut(i).assign(&unperm_rv.row(ord));
     }
-    (rv.reversed_axes(), logp)
+    rv.reversed_axes()
 }
 
 /// truncated multivariate normal generator
@@ -327,7 +326,7 @@ pub fn mv_truncnormal_rand<R: Rng + ?Sized>(
     n: usize,
     max_iters: usize,
     rng: &mut R,
-) -> (Array2<f64>, Array1<f64>) {
+) -> Array2<f64> {
     let d = l.len();
     let (Lfull, perm) = cholperm(&mut sigma, &mut l, &mut u);
     let D = Lfull.diag().to_owned();
@@ -338,14 +337,10 @@ pub fn mv_truncnormal_rand<R: Rng + ?Sized>(
 
     // find optimal tilting parameter via non-linear equation solver
     let problem = TiltingProblem::new(l.clone(), u.clone(), sigma);
-    //let (result, _report) = LevenbergMarquardt::new().minimize(problem);
-    problem.solve_optimial_tilting();
-    let x = Array1::zeros(10);
-    let mu = Array1::zeros(10);
-
-    //let x = result.get_x().slice(s![..d - 1]).to_owned();
+    let result = problem.solve_optimial_tilting();
     // assign saddlepoint x* and mu*
-    //let mu = result.get_x().slice(s![d - 1..(2 * (d - 1))]).to_owned();
+    let x = result.x.slice(s![..d - 1]).to_owned();
+    let mu = result.x.slice(s![d - 1..(2 * (d - 1))]).to_owned();
     let psi_star = psy(&x, &L, &l, &u, &mu); // compute psi star
     let (logp, mut Z) = mv_truncnorm_proposal(&L, &l, &u, &mu, n, max_iters, rng);
 
@@ -373,7 +368,6 @@ pub fn mv_truncnormal_rand<R: Rng + ?Sized>(
         accept_condition(&logp, &mut accepted, rng);
         i += 1;
         if i > max_iters {
-            //println!("Ran out of accept-reject rounds");
             break;
         }
     }
@@ -388,7 +382,7 @@ pub fn mv_truncnormal_rand<R: Rng + ?Sized>(
     for (i, &ord) in order.iter().enumerate() {
         rv.row_mut(i).assign(&unperm_rv.row(ord));
     }
-    (rv.reversed_axes(), logp)
+    rv.reversed_axes()
 }
 
 pub fn solved_mv_truncnormal_cdf<R: Rng + ?Sized>(
@@ -485,7 +479,6 @@ mod tests {
         let n = 10;
         let max_iters = 10;
         let samples = mv_truncnormal_rand(l, u, sigma, n, max_iters, &mut rng);
-        println!("samples: {:?}", samples);
     }
 
     #[bench]
